@@ -15,7 +15,7 @@ use Tags::HTML::Page::Begin;
 use Tags::HTML::Page::End;
 use Tags::Output::Raw;
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub call {
 	my ($self, $env) = @_;
@@ -34,6 +34,7 @@ sub call {
 	$self->_css;
 	$self->_tags;
 	$self->tags->finalize;
+	$self->_cleanup;
 
 	return [
 		$self->status_code,
@@ -100,6 +101,12 @@ sub prepare_app {
 	return;
 }
 
+sub _cleanup {
+	my $self = shift;
+
+	return;
+}
+
 sub _css {
 	my $self = shift;
 
@@ -178,6 +185,12 @@ Plack::Component::Tags::HTML - Plack component for Tags with HTML output.
 
  use base qw(Plack::Component::Tags::HTML);
 
+ sub _cleanup {
+        my $self = shift;
+        # Cleanup about call().
+        return;
+ }
+
  sub _css {
         my $self = shift;
         $self->{'css'}->put(
@@ -294,6 +307,11 @@ Default value is
 
 =head1 METHODS TO OVERWRITE
 
+=head2 C<_cleanup>
+
+Method to cleanup after C<call()>.
+Argument is C<$self> only.
+
 =head2 C<_css>
 
 Method to set css via C<$self-E<gt>{'css'}> object.
@@ -324,6 +342,7 @@ There is run of:
  $self->_process_actions($env);
  $self->_css;
  $self->_tags;
+ $self->_cleanup;
 
 After it Generate and encode output from Tags to output with HTTP code.
 HTTP status code is defined by C<status_code()> method and Content-Type is
@@ -480,6 +499,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
